<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Đã kích hoạt chế độ máy bay</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Đã tắt chế độ máy bay</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Kích hoạt</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Chế độ máy bay</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Cài đặt chế độ máy bay</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Chế độ máy bay</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Điết bị của tôi</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Cài đặt Blurtooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Cài đặt Blurtooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 đã kết nối</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Đang kết nối...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Đã tắt</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Kết nối %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Chưa kết nối</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Tắt</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Độ sáng</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Cài đặt màn hình</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Cài đặt màn hình</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Độ sáng</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>CN</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>TH</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>TU</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>WE</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>TH</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>CN</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>CU</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Thêm bố cục bàn phím</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Ngày giờ</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Chế độ 12 giờ</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Chế độ 24 giờ</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Cài đặt thời gian</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Mở lịch</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Thứ hai</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Thứ ba</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Thứ tư</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Thứ năm</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Thứ sáu</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Thứ bảy</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Chủ nhật</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>thứ hai</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>thứ hai</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>thứ ba</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>thứ tư</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>thứ năm</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>thứ sáu</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>chủ nhật</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Các thiết bị khác</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Chế độ KH</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Cài đặt chế độ KH</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Bật</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Chế độ KH đã bật</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Chế độ KH đã tắt</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Chế độ KH</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Độ thoải mắt</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Độ thoải mắt đã bật</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Độ thoải mắt đã tắt</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Cài đặt màn hình</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Độ thoải mắt</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Bật</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Sáng</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Đêm</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Tắt chế độ bảo vệ mắt</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Kích hoạt chế độ bảo vệ mắt</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Cài đặt hiển thị</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: Sáng</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: Đen</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: Tự động</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Hiệu ứng thị giác</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Sáng</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Đen</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Không có thông báo</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Cài đặt thông báo</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Thông báo</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Tắt chế độ Không làm phiền</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Kích hoạt chế độ Không làm phiền</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Thông báo</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Cài đặt</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Độ hiệu năng cao</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Đa năng suất</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Lưu điện</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Đa hiệu năng</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Thiết lập năng lượng</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Năng lượng %1, %2 còn lại</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Năng lượng %1, %2 giờ %3 phút còn lại</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Đang sạc %1, %2 phút sẽ đầy</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Đang sạc %1, %2 giờ %3 phút sẽ đầy</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Phù hợp %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Đang nạp %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Công suất 1%...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Công suất 1%, sạc đã đầy</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Dung lượng %1, không sạc</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Pin</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Sạc, tính toán thời gian sạc ước lượng</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Đang tính thời gian sử dụng còn lại</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 phút còn lại</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 giờ %2 phút còn lại</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Không đang sạc</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Đã sạc đầy</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Đang sạc, %1 phút nữa đầy</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Đang sạc, %1 giờ %2 phút nữa đầy</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Dung lượng %1, %2 giờ còn lại</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 giờ còn lại</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Đang sạc %1, %2 giờ nữa đầy</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Đang sạc, %1 giờ nữa đầy</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Âm nhạc</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Không rõ</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Tắt máy</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Dừng</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ngủ đông</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Khóa</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Thoát ra</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Thiết lập năng lượng</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Khởi động lại</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Cập nhật và tắt máy</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Cập nhật và khởi động lại</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Tắt máy</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Đổi người dùng</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Hôm nay</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>Năm</translation>
    </message>
    <message>
        <source>m</source>
        <translation>Tháng</translation>
    </message>
    <message>
        <source>d</source>
        <translation>Ngày</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation>Tháng 1</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Tháng 2</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Tháng 3</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Tháng 4</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Tháng 5</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Tháng 6</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Tháng 7</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Tháng 8</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Tháng 9</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Tháng 10</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Tháng 11</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Tháng 12</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Mở lịch</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Thứ Hai</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Thứ Ba</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Thứ Tư</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Thứ Năm</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Thứ Sáu</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Thứ Bảy</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>Chủ Nhật</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Âm lượng</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Thiết lập ra</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Cài đặt âm thanh</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Âm thanh</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Tắt tiếng</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Kích tiếng</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Cài đặt âm thanh</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Không có thiết bị ra</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Tăng âm lượng %1</translation>
    </message>
</context>
</TS>